@@ -18,12 +18,10 @@ class CommandParse(Command):
         opt('--port', description='Server\'s port number.'),
         opt('--username', alias=['-u'], description='Login username.'),
         opt('--password', alias=['-P'], description='Login password.'),
+        opt('--help', alias=['-h'], description='Show this help message.', is_help=True),
     ])
 
     def execute(self, words):
-        if '-h' in words or '--help' in words or len(words) == 0:
-            print(self.help(), end='')
-            return
         args, opts = self.parser.parse(words)
         print(args)
         print(opts)
@@ -38,10 +36,12 @@ class MyCli(CommandLineInterface):
         'parse': CommandParse,
     }
 
+    parser = Parser([
+        opt('--help', alias=['-h'], description='Show this help message.', is_help=True),
+    ])
+
     def execute(self, words):
-        if '-h' in words or '--help' in words or len(words) == 0:
-            print(self.help(), end='')
-            return
+        _args, _opts = self.parser.parse(words)
 
 
 if __name__ == '__main__':
