@@ -1,4 +1,4 @@
-from moco import InteractiveInterface, Command, Parser, opt
+from moco import InteractiveInterface, Command, Parser, opt, opt_help
 
 
 class CommandHello(Command):
@@ -18,6 +18,7 @@ class CommandParse(Command):
         opt('--port', description='Server\'s port number.'),
         opt('--username', alias=['-u'], description='Login username.'),
         opt('--password', alias=['-P'], description='Login password.'),
+        opt_help(),
     ])
 
     def execute(self, words):
